@@ -1,6 +1,7 @@
 import sys
 from threading import Event, RLock, Thread
-from typing import IO, Any, Callable, List, Optional
+from types import TracebackType
+from typing import IO, Any, Callable, List, Optional, TextIO, Type, cast
 
 from . import get_console
 from .console import Console, ConsoleRenderable, RenderableType, RenderHook
@@ -39,7 +40,7 @@ class Live(JupyterMixin, RenderHook):
         console (Console, optional): Optional Console instance. Default will an internal Console instance writing to stdout.
         screen (bool, optional): Enable alternate screen mode. Defaults to False.
         auto_refresh (bool, optional): Enable auto refresh. If disabled, you will need to call `refresh()` or `update()` with refresh flag. Defaults to True
-        refresh_per_second (float, optional): Number of times per second to refresh the live display. Defaults to 1.
+        refresh_per_second (float, optional): Number of times per second to refresh the live display. Defaults to 4.
         transient (bool, optional): Clear the renderable on exit (has no effect when screen=True). Defaults to False.
         redirect_stdout (bool, optional): Enable redirection of stdout, so ``print`` may be used. Defaults to True.
         redirect_stderr (bool, optional): Enable redirection of stderr. Defaults to True.
@@ -49,9 +50,9 @@ class Live(JupyterMixin, RenderHook):
 
     def __init__(
         self,
-        renderable: RenderableType = None,
+        renderable: Optional[RenderableType] = None,
         *,
-        console: Console = None,
+        console: Optional[Console] = None,
         screen: bool = False,
         auto_refresh: bool = True,
         refresh_per_second: float = 4,
@@ -59,7 +60,7 @@ class Live(JupyterMixin, RenderHook):
         redirect_stdout: bool = True,
         redirect_stderr: bool = True,
         vertical_overflow: VerticalOverflowMethod = "ellipsis",
-        get_renderable: Callable[[], RenderableType] = None,
+        get_renderable: Optional[Callable[[], RenderableType]] = None,
     ) -> None:
         assert refresh_per_second > 0, "refresh_per_second must be > 0"
         self._renderable = renderable
@@ -86,7 +87,11 @@ class Live(JupyterMixin, RenderHook):
         self._live_render = LiveRender(
             self.get_renderable(), vertical_overflow=vertical_overflow
         )
-        # cant store just clear_control as the live_render shape is lazily computed on render
+
+    @property
+    def is_started(self) -> bool:
+        """Check if live display has been started."""
+        return self._started
 
     def get_renderable(self) -> RenderableType:
         renderable = (
@@ -96,7 +101,7 @@ class Live(JupyterMixin, RenderHook):
         )
         return renderable or ""
 
-    def start(self, refresh=False) -> None:
+    def start(self, refresh: bool = False) -> None:
         """Start live rendering display.
 
         Args:
@@ -159,26 +164,31 @@ class Live(JupyterMixin, RenderHook):
         self.start(refresh=self._renderable is not None)
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
+    def __exit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_val: Optional[BaseException],
+        exc_tb: Optional[TracebackType],
+    ) -> None:
         self.stop()
 
-    def _enable_redirect_io(self):
+    def _enable_redirect_io(self) -> None:
         """Enable redirecting of stdout / stderr."""
         if self.console.is_terminal:
-            if self._redirect_stdout and not isinstance(sys.stdout, FileProxy):  # type: ignore
+            if self._redirect_stdout and not isinstance(sys.stdout, FileProxy):
                 self._restore_stdout = sys.stdout
-                sys.stdout = FileProxy(self.console, sys.stdout)
-            if self._redirect_stderr and not isinstance(sys.stderr, FileProxy):  # type: ignore
+                sys.stdout = cast("TextIO", FileProxy(self.console, sys.stdout))
+            if self._redirect_stderr and not isinstance(sys.stderr, FileProxy):
                 self._restore_stderr = sys.stderr
-                sys.stderr = FileProxy(self.console, sys.stderr)
+                sys.stderr = cast("TextIO", FileProxy(self.console, sys.stderr))
 
-    def _disable_redirect_io(self):
+    def _disable_redirect_io(self) -> None:
         """Disable redirecting of stdout / stderr."""
         if self._restore_stdout:
-            sys.stdout = self._restore_stdout
+            sys.stdout = cast("TextIO", self._restore_stdout)
             self._restore_stdout = None
         if self._restore_stderr:
-            sys.stderr = self._restore_stderr
+            sys.stderr = cast("TextIO", self._restore_stderr)
             self._restore_stderr = None
 
     @property
@@ -205,17 +215,17 @@ class Live(JupyterMixin, RenderHook):
 
     def refresh(self) -> None:
         """Update the display of the Live Render."""
-        self._live_render.set_renderable(self.renderable)
-        if self.console.is_jupyter:  # pragma: no cover
-            try:
-                from IPython.display import display
-                from ipywidgets import Output
-            except ImportError:
-                import warnings
+        with self._lock:
+            self._live_render.set_renderable(self.renderable)
+            if self.console.is_jupyter:  # pragma: no cover
+                try:
+                    from IPython.display import display
+                    from ipywidgets import Output
+                except ImportError:
+                    import warnings
 
-                warnings.warn('install "ipywidgets" for Jupyter support')
-            else:
-                with self._lock:
+                    warnings.warn('install "ipywidgets" for Jupyter support')
+                else:
                     if self.ipy_widget is None:
                         self.ipy_widget = Output()
                         display(self.ipy_widget)
@@ -223,14 +233,14 @@ class Live(JupyterMixin, RenderHook):
                     with self.ipy_widget:
                         self.ipy_widget.clear_output(wait=True)
                         self.console.print(self._live_render.renderable)
-        elif self.console.is_terminal and not self.console.is_dumb_terminal:
-            with self._lock, self.console:
-                self.console.print(Control())
-        elif (
-            not self._started and not self.transient
-        ):  # if it is finished allow files or dumb-terminals to see final result
-            with self.console:
-                self.console.print(Control())
+            elif self.console.is_terminal and not self.console.is_dumb_terminal:
+                with self.console:
+                    self.console.print(Control())
+            elif (
+                not self._started and not self.transient
+            ):  # if it is finished allow files or dumb-terminals to see final result
+                with self.console:
+                    self.console.print(Control())
 
     def process_renderables(
         self, renderables: List[ConsoleRenderable]
